@@ -1,7 +1,9 @@
 package App::seq::pl;
 
-our $DATE = '2016-12-16'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-07-17'; # DATE
+our $DIST = 'App-seq-pl'; # DIST
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Like seq, but with Perl extras
@@ -18,7 +20,7 @@ App::seq::pl - Like seq, but with Perl extras
 
 =head1 VERSION
 
-This document describes version 0.001 of App::seq::pl (from Perl distribution App-seq-pl), released on 2016-12-16.
+This document describes version 0.002 of App::seq::pl (from Perl distribution App-seq-pl), released on 2021-07-17.
 
 =head1 HOMEPAGE
 
@@ -42,7 +44,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
